(ns jambda.views
  (:require
   [re-frame.core :as re-frame]
   [clojure.string :as string]
   [goog.string :as gstr]
   [jambda.config :as config]
   [jambda.styles :as styles]
   [jambda.subs :as subs]))

(defn- join-lines [coll]
    (string/join \newline coll))

(defn- comma-separated [coll]
    (string/join ", " coll))

(defn- parenthesize [s]
    (when s (str "(" s ")")))

(defn- spaced [& elements]
    (string/join " " (filter identity elements)))


(defn- link-to [href & content]
    [:a {:href href} content])

(def agpl-link
    (link-to
     "https://www.gnu.org/licenses/agpl-3.0.html"
     "GNU Affero Public License"))

(def uberspace-link
    (link-to
     "https://uberspace.de/"
     "Uberspace"))

(defn footer []
  [:footer {:class (styles/footer)}
   [:span.license agpl-link]
   [:span.version (spaced "version:" config/version)]
   [:span.host "Hosted by " uberspace-link]])

(defn title []
  (let [name (re-frame/subscribe [::subs/name])]
    [:h1 "Welcome to " @name]))
   
(defn main-panel []
  [:div {:class (styles/screen)}
   [:div {:class (styles/main-panel)}
    [title] [footer]]])
